API Shark - Test Coverage Report

## CloudVector API Shark - Test Coverage Report

API Shark Test window: 08, Feb 2020 to 15, Feb 2020 APIs: 164 | Parameters: 14 | APIs with Auth: 4 | API Calls: 75257 API Baseline file: input.json APIs: 5 | Parameters: 15 | APIs with Auth: 0 | # 84/100 Overall Coverage Score

API Coverage details:

mandatory | password - client_id - grant_type - email - client_secret -
optional |
Response Codes | 401 ? 200 ?

mandatory params (coverage: 100%)
optional params (coverage: 0%)

mandatory | user_idw - description - amount - account_id -
optional | beneficiary_id -
Response Codes | 201 ?

mandatory params (coverage: 75%)
optional params (coverage: 100%)

mandatory | user_detail -
optional |
Response Codes | 200 400

mandatory params (coverage: 100%)
optional params (coverage: 0%)

mandatory | description - amount - user_id - account_id -
optional |
Response Codes | 201 ?

mandatory params (coverage: 100%)
optional params (coverage: 0%)

## Missing API(s) details:

/user_detail |

## Missing Parameter(s) details:

/transfers |

#### Community Edition: http://34.238.148.157:31316

#### Recording: